From: Duy Nguyen Date: Sun, 20 Jul 2014 12:50:03 GMT Subject: Re: [PATCH v2 1/2] lockfile.c: remove PATH_MAX limitation (except in resolve_symlink) Message-ID: In-Reply-To: <232C089CF449490C9F5B398996DD314C@PhilipOakley> On Sun, Jul 20, 2014 at 7:47 PM, Philip Oakley wrote: > From: "Nguyễn Thái Ngọc Duy" > >> Something extra is, because struct lock_file is usually used as static >> variables in many places. This patch reduces bss section by about 80k >> bytes (or 23%) on Linux. > > > This didn't scan for me. Perhaps it's the punctuation. Maybe: > > Additionally, because the struct lock_file variables are [were] in many > places static, this patch reduces the bss section size by about 80k > > bytes (or 23%) on Linux. > > Does my tweak reflect your intent? Yes. But I should probably put that below the "---" line. We're not busybox. 80k is pratically nothing. -- Duy